@@ -98,7 +98,7 @@ class TorchFitter:
             if self.verbose > 0:
                 lr = self.optimizer.param_groups[0]['lr']
                 timestamp = datetime.utcnow().isoformat()
-                self.log(f'\n{timestamp}\nEPOCH{str(self.epoch)}/{str(n_epochs)} - LR: {lr}')
+                self.log(f'\n{timestamp}\nEPOCH {str(self.epoch)}/{str(n_epochs)} - LR: {lr}')
 
             # Run one training epoch
             t = time.time()
@@ -122,8 +122,8 @@ class TorchFitter:
             #         f'metric {calculated_metric},' if calculated_metric else '' +\
             #         f'time: {(time.time() - t):.2f}')
 
-            self.log(f'[RESULT] {(time.time() - t):.5f}s - train loss: {train_summary_loss.avg:.5f} - val loss: {val_summary_loss.avg:.5f} ' + \
-                    f'metric {calculated_metric},' if calculated_metric else '' )
+            metric_log = f'metric {calculated_metric},' if calculated_metric else ''
+            self.log(f'[RESULT] {(time.time() - t):.2f}s - train loss: {train_summary_loss.avg:.5f} - val loss: {val_summary_loss.avg:.5f} ' + metric_log)
 
             if calculated_metric:
                 history['val_metric'] = calculated_metric
